# DIP

## Original code

[https://github.com/zihuazheng/DIP](https://github.com/zihuazheng/DIP)

## Code license

See [LICENSE](LICENSE).

## Pretrained weights license

Not specified.

## Citation

```
@InProceedings{Zheng2022DIPDeepInverse,
  author    = {Zihua Zheng and Ni Nie and Zhi Ling and Pengfei Xiong and Jiangyu Liu and Hongya Wang and Jiankun Li},
  booktitle = {CVPR},
  title     = {{DIP}: Deep Inverse Patchmatch for High-Resolution Optical Flow},
  year      = {2022},
  pages     = {8915-8924},
}
```